@@ -319,9 +319,9 @@ sub addvalues {
 			# ldapbrowser.xml<nl>http://www.tilburguniversity.edu/nl/webwijs/show/?uid=anton.sluijtman</nl>
 			#
 			if ($value =~ /webwijs\/show/) {
-				my ($label) = $value =~ /webwijs\/show(\?.+)/;
+				my ($identifier) = $value =~ /webwijs\/show(\?.+)/;
 				my $url = $self->{fields}->{babelfish}->translate('webwijsUrl');
-				$value = "${url}$label" if $label;
+				$value = "${url}$identifier";
 			}
 
 			my $h = $self->{fields}->{babelfish}->translate($attr, {'title' => 1});
